@@ -27,13 +27,12 @@ DEPLOY=1
 ENABLE_FREI0R=1
 FREI0R_HEAD=1
 FREI0R_REVISION=
-ENABLE_MOVIT=1
 SUBDIRS=
+ENABLE_MOVIT=1
 MOVIT_HEAD=0
 MOVIT_REVISION="origin/shotcut-opengl3"
-ENABLE_SWH_PLUGINS=0
 FFMPEG_HEAD=0
-FFMPEG_REVISION="origin/release/6.0"
+FFMPEG_REVISION="origin/release/7.1"
 FFMPEG_ADDITIONAL_OPTIONS=
 MLT_HEAD=1
 MLT_REVISION=
@@ -43,30 +42,39 @@ SHOTCUT_REVISION=
 SHOTCUT_VERSION=$(date '+%y.%m.%d')
 ENABLE_BIGSH0T=1
 BIGSH0T_HEAD=0
-BIGSH0T_REVISION="8fe56f6d4e"
-ENABLE_ZIMG=1
-ZIMG_HEAD=0
-ZIMG_REVISION="51c3c7f750c2af61955377faad56e3ba1b03589f"
+BIGSH0T_REVISION="710e734512b8975722f0c41f793f28c51a3d2b88"
 DAV1D_HEAD=0
-DAV1D_REVISION="1.2.0"
+DAV1D_REVISION="1.5.0"
 AOM_HEAD=0
-AOM_REVISION="v3.6.0"
+AOM_REVISION="v3.11.0"
 ENABLE_VMAF=1
 VMAF_HEAD=0
-VMAF_REVISION="v2.3.1"
+VMAF_REVISION="v3.0.0"
 ENABLE_GLAXNIMATE=1
 GLAXNIMATE_HEAD=0
-GLAXNIMATE_REVISION="v0.5.3"
+GLAXNIMATE_REVISION="origin/v0.5.4"
 ENABLE_GOPRO2GPX=1
 ENABLE_OPENCV=1
 OPENCV_HEAD=0
-OPENCV_REVISION="4.7.0"
-
-# QT_INCLUDE_DIR="$(pkg-config --variable=prefix QtCore)/include"
-QT_INCLUDE_DIR=${QTDIR:+${QTDIR}/include}
-# QT_LIB_DIR="$(pkg-config --variable=prefix QtCore)/lib"
-QT_LIB_DIR=${QTDIR:+${QTDIR}/lib}
+OPENCV_REVISION="origin/4.x"
+OPENCV_CONTRIB_HEAD=0
+OPENCV_CONTRIB_REVISION="4.11.0"
+ENABLE_LIBSPATIALAUDIO=1
+LIBSPATIALAUDIO_HEAD=0
+LIBSPATIALAUDIO_REVISION="origin/patch-1"
+ENABLE_LADSPA=1
+LADSPA_HEAD=0
+LADSPA_REVISION="origin/shotcut"
 MLT_DISABLE_SOX=0
+ENABLE_WHISPERCPP=1
+WHISPERCPP_HEAD=0
+WHISPERCPP_REVISION="v1.7.4"
+NV_CODEC_REVISION="sdk/12.0"
+
+PYTHON_VERSION=$(python3 --version | awk '{split($2, parts, "."); print parts[1] "." parts[2]}')
+PYTHON_VERSION_DLL=$(python3 --version | awk '{split($2, parts, "."); print parts[1]parts[2]}')
+
+QT_VERSION_X64="6.9.1"
 
 ################################################################################
 # Location of config file - if not overridden on command line
@@ -101,8 +109,9 @@ function usage {
 # Parses the arguments passed in $@ and sets some global vars
 function parse_args {
   CONFIGFILEOPT=""
-  while getopts ":tsc:o:v:" OPT; do
+  while getopts ":tsc:a:o:v:" OPT; do
     case $OPT in
+      a ) TARGET_ARCH=$OPTARG;;
       c ) CONFIGFILEOPT=$OPTARG
           echo Setting configfile to $CONFIGFILEOPT
       ;;
@@ -150,7 +159,7 @@ function to_key {
     shotcut)
       echo 4
     ;;
-    swh-plugins)
+    ladspa-swh)
       echo 5
     ;;
     nv-codec-headers)
@@ -162,7 +171,7 @@ function to_key {
     bigsh0t)
       echo 8
     ;;
-    zimg)
+    whisper.cpp)
       echo 9
     ;;
     dav1d)
@@ -186,6 +195,9 @@ function to_key {
     opencv_contrib)
       echo 16
     ;;
+    libspatialaudio)
+      echo 17
+    ;;
     *)
       echo UNKNOWN
     ;;
@@ -330,6 +342,20 @@ function set_globals {
   fi
   export LDFLAGS=
 
+  # Set Qt installation variables.
+  test "$TARGET_ARCH" = "" && TARGET_ARCH=${MSYSTEM,,}
+  if [ "$TARGET_ARCH" = "clangarm64" ]; then
+    export QTDIR="$(pkg-config --variable=prefix Qt6Core)"
+    QT_INCLUDE_DIR="$QTDIR/qt6/include"
+    QT_LIB_DIR="$QTDIR/lib"
+    QT_SHARE_DIR="$QTDIR/share/qt6"
+  else
+    export QTDIR="$HOME/Qt/$QT_VERSION_X64/mingw_64"
+    QT_INCLUDE_DIR="$QTDIR/include"
+    QT_LIB_DIR="$QTDIR/lib"
+    QT_SHARE_DIR="$QTDIR"
+  fi
+
   # Set convenience variables.
   if test 1 = "$ACTION_GET" ; then
     GET=1
@@ -352,10 +378,9 @@ function set_globals {
   # Subdirs list, for number of common operations
   # Note, the function to_key depends on this
   if [ -z "$SUBDIRS" ]; then
-    SUBDIRS="aom dav1d AMF nv-codec-headers FFmpeg"
-    if test "$ENABLE_SWH_PLUGINS" = "1"; then
-        SUBDIRS="$SUBDIRS swh-plugins"
-    fi
+    [ "$TARGET_ARCH" = "mingw64" ] && SUBDIRS="AMF nv-codec-headers"
+    SUBDIRS="$SUBDIRS aom dav1d FFmpeg"
+
     if test "$ENABLE_MOVIT" = 1 && test "$MOVIT_HEAD" = 1 -o "$MOVIT_REVISION" != ""; then
         SUBDIRS="$SUBDIRS movit"
     fi
@@ -365,9 +390,6 @@ function set_globals {
     if test "$ENABLE_BIGSH0T" = 1 ; then
         SUBDIRS="$SUBDIRS bigsh0t"
     fi
-    if test "$ENABLE_ZIMG" = 1 ; then
-        SUBDIRS="zimg $SUBDIRS"
-    fi
     if test "$ENABLE_VMAF" = 1 ; then
         SUBDIRS="vmaf $SUBDIRS"
     fi
@@ -380,6 +402,15 @@ function set_globals {
     if test "$ENABLE_OPENCV" = 1 ; then
         SUBDIRS="opencv opencv_contrib $SUBDIRS"
     fi
+    if test "$ENABLE_LIBSPATIALAUDIO" = 1  && test "$LIBSPATIALAUDIO_HEAD" = 1 -o "$LIBSPATIALAUDIO_REVISION" != ""; then
+        SUBDIRS="libspatialaudio $SUBDIRS"
+    fi
+    if test "$ENABLE_LADSPA" = 1 && test "$LADSPA_HEAD" = 1 -o "$LADSPA_REVISION" != ""; then
+        SUBDIRS="ladspa-swh $SUBDIRS"
+    fi
+    if test "$ENABLE_WHISPERCPP" = 1  && test "$WHISPERCPP_HEAD" = 1 -o "$WHISPERCPP_REVISION" != ""; then
+        SUBDIRS="whisper.cpp $SUBDIRS"
+    fi
     SUBDIRS="$SUBDIRS mlt shotcut"
   fi
 
@@ -409,19 +440,20 @@ function set_globals {
   REPOLOCS[2]="https://github.com/dyne/frei0r.git"
   REPOLOCS[3]="https://github.com/ddennedy/movit.git"
   REPOLOCS[4]="https://github.com/mltframework/shotcut.git"
-  REPOLOCS[5]="http://ftp.us.debian.org/debian/pool/main/s/swh-plugins/swh-plugins_0.4.15+1.orig.tar.gz"
+  REPOLOCS[5]="https://github.com/ddennedy/ladspa-swh.git"
   REPOLOCS[6]="https://github.com/FFmpeg/nv-codec-headers.git"
   REPOLOCS[7]="https://github.com/GPUOpen-LibrariesAndSDKs/AMF.git"
 #  REPOLOCS[8]="https://bitbucket.org/dandennedy/bigsh0t.git"
   REPOLOCS[8]="https://bitbucket.org/leo_sutic/bigsh0t.git"
-  REPOLOCS[9]="https://github.com/sekrit-twc/zimg.git"
-  REPOLOCS[10]="https://code.videolan.org/videolan/dav1d.git"
+  REPOLOCS[9]="https://github.com/ggerganov/whisper.cpp.git"
+  REPOLOCS[10]="https://github.com/videolan/dav1d.git"
   REPOLOCS[11]="https://aomedia.googlesource.com/aom"
   REPOLOCS[12]="https://github.com/Netflix/vmaf.git"
   REPOLOCS[13]="https://gitlab.com/ddennedy/glaxnimate.git"
   REPOLOCS[14]="https://github.com/ddennedy/gopro2gpx.git"
   REPOLOCS[15]="https://github.com/opencv/opencv.git"
   REPOLOCS[16]="https://github.com/opencv/opencv_contrib.git"
+  REPOLOCS[17]="https://github.com/ddennedy/libspatialaudio.git"
 
   # REPOTYPE Array holds the repo types. (Yes, this might be redundant, but easy for me)
   REPOTYPES[0]="git"
@@ -429,7 +461,7 @@ function set_globals {
   REPOTYPES[2]="git"
   REPOTYPES[3]="git"
   REPOTYPES[4]="git"
-  REPOTYPES[5]="http-tgz"
+  REPOTYPES[5]="git"
   REPOTYPES[6]="git"
   REPOTYPES[7]="git"
   REPOTYPES[8]="git"
@@ -441,6 +473,7 @@ function set_globals {
   REPOTYPES[14]="git"
   REPOTYPES[15]="git"
   REPOTYPES[16]="git"
+  REPOTYPES[17]="git"
 
   # And, set up the revisions
   REVISIONS[0]=""
@@ -463,16 +496,19 @@ function set_globals {
   if test 0 = "$SHOTCUT_HEAD" -a "$SHOTCUT_REVISION" ; then
     REVISIONS[4]="$SHOTCUT_REVISION"
   fi
-  REVISIONS[5]="swh-plugins-0.4.15+1"
-  REVISIONS[6]="sdk/8.1" # nv-codec-headers
+  REVISIONS[5]=""
+  if test 0 = "$LADSPA_HEAD" -a "$LADSPA_REVISION" ; then
+    REVISIONS[5]="$LADSPA_REVISION"
+  fi
+  REVISIONS[6]="$NV_CODEC_REVISION"
   REVISIONS[7]="" # AMF
   REVISIONS[8]=""
   if test 0 = "$BIGSH0T_HEAD" -a "$BIGSH0T_REVISION" ; then
     REVISIONS[8]="$BIGSH0T_REVISION"
   fi
   REVISIONS[9]=""
-  if test 0 = "$ZIMG_HEAD" -a "$ZIMG_REVISION" ; then
-    REVISIONS[9]="$ZIMG_REVISION"
+  if test 0 = "$WHISPERCPP_HEAD" -a "$WHISPERCPP_REVISION" ; then
+    REVISIONS[9]="$WHISPERCPP_REVISION"
   fi
   REVISIONS[10]=""
   if test 0 = "$DAV1D_HEAD" -a "$DAV1D_REVISION" ; then
@@ -496,8 +532,12 @@ function set_globals {
     REVISIONS[15]="$OPENCV_REVISION"
   fi
   REVISIONS[16]=""
-  if test 0 = "$OPENCV_HEAD" -a "$OPENCV_REVISION" ; then
-    REVISIONS[16]="$OPENCV_REVISION"
+  if test 0 = "$OPENCV_CONTRIB_HEAD" -a "$OPENCV_CONTRIB_REVISION" ; then
+    REVISIONS[16]="$OPENCV_CONTRIB_REVISION"
+  fi
+  REVISIONS[17]=""
+  if test 0 = "$LIBSPATIALAUDIO_HEAD" -a "$LIBSPATIALAUDIO_REVISION" ; then
+    REVISIONS[17]="$LIBSPATIALAUDIO_REVISION"
   fi
 
   # Figure out the number of cores in the system. Used both by make and startup script
@@ -520,7 +560,6 @@ function set_globals {
 
   # set global environment for all jobs
   alias make=mingw32-make
-  export QTDIR="$HOME/Qt/6.4.2/mingw_64"
   export PKG_CONFIG_PATH="$HOME/lib/pkgconfig:$PKG_CONFIG_PATH"
   export PATH="$FINAL_INSTALL_DIR/bin:$PATH"
   export LD_RUN_PATH="$FINAL_INSTALL_DIR/lib"
@@ -533,20 +572,18 @@ function set_globals {
   #####
   # ffmpeg
   CONFIG[0]="./configure --prefix=$FINAL_INSTALL_DIR --disable-static --disable-doc --enable-gpl --enable-version3 --enable-shared --enable-runtime-cpudetect $CONFIGURE_DEBUG_FLAG"
-  CONFIG[0]="${CONFIG[0]} --enable-libtheora --enable-libvorbis --enable-libmp3lame --enable-libx264 --enable-libx265 --enable-libvpx --enable-libopus --enable-libvpl --enable-libdav1d --enable-libaom --disable-decoder=libaom_av1 --enable-libwebp --disable-vulkan"
+  CONFIG[0]="${CONFIG[0]} --enable-libtheora --enable-libvorbis --enable-libmp3lame --enable-libx264 --enable-libx265 --enable-libvpx --enable-libopus --enable-libvpl --enable-libdav1d --enable-libaom --disable-decoder=libaom_av1 --enable-libsvtav1 --enable-libwebp --enable-libzimg --disable-vulkan --disable-vaapi"
+  [ "$TARGET_ARCH" = "clangarm64" ] && CONFIG[0]="${CONFIG[0]} --cc=clang --cxx=clang++ --arch=aarch64"
   # Add optional parameters
-  if [ "$ENABLE_ZIMG" = "1" ]; then
-    CONFIG[0]="${CONFIG[0]} --enable-libzimg"
-  fi
   if [ "$ENABLE_VMAF" = "1" ]; then
     CONFIG[0]="${CONFIG[0]} --enable-libvmaf --disable-w32threads"
   fi
   CONFIG[0]="${CONFIG[0]} $FFMPEG_ADDITIONAL_OPTIONS"
-  CFLAGS_[0]="-I$FINAL_INSTALL_DIR/include $CFLAGS"
+  CFLAGS_[0]="-I$FINAL_INSTALL_DIR/include  -Wno-incompatible-pointer-types $CFLAGS"
 
   #####
   # mlt
-  CONFIG[1]="cmake -GNinja -DCMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -DCMAKE_PREFIX_PATH=$QTDIR -DMOD_GDK=OFF -DMOD_GLAXNIMATE_QT6=ON -DMOD_QT=OFF -DMOD_QT6=ON -DMOD_SDL1=OFF"
+  CONFIG[1]="cmake -GNinja -DCMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -DCMAKE_PREFIX_PATH=$QTDIR -DMOD_GDK=OFF -DMOD_GLAXNIMATE_QT6=ON -DMOD_QT=OFF -DMOD_QT6=ON -DMOD_SDL1=OFF -DUSE_VST2=OFF"
   [ "$ENABLE_OPENCV" = "1" ] && CONFIG[1]="${CONFIG[1]} -DMOD_OPENCV=ON"
   if [ "$DEBUG_BUILD" = "1" ]; then
     CONFIG[1]="${CONFIG[1]} -DCMAKE_BUILD_TYPE=RelWithDebInfo"
@@ -585,10 +622,12 @@ function set_globals {
   INSTALL[4]="install_shotcut"
 
   #####
-  # swh-plugins
-  CONFIG[5]="./configure --prefix=$FINAL_INSTALL_DIR --enable-sse"
+  # ladspa-swh
+  CONFIG[5]="./autogen.sh --prefix=$FINAL_INSTALL_DIR --disable-nls"
   CFLAGS_[5]=$CFLAGS
   LDFLAGS_[5]=$LDFLAGS
+  BUILD[5]="make -j $MAKEJ LDFLAGS=-no-undefined"
+  INSTALL[5]="install_ladspa-swh"
 
   #######
   # nv-codec-headers
@@ -608,11 +647,17 @@ function set_globals {
   INSTALL[8]="install -p -c *.dll "$FINAL_INSTALL_DIR"/lib/frei0r-1"
 
   #####
-  # zimg
-  [ ! -e "$SOURCE_DIR"/zimg/configure ] && PRECONFIG[9]="./autogen.sh"
-  CONFIG[9]="./configure --prefix=$FINAL_INSTALL_DIR"
+  # whisper.cpp
+  CONFIG[9]="cmake -B build -G Ninja -D CMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR $CMAKE_DEBUG_FLAG -D BUILD_SHARED_LIBS=ON -D GGML_NATIVE=OFF -D WHISPER_BUILD_SERVER=OFF -D WHISPER_BUILD_TESTS=OFF"
+  if [ "$TARGET_ARCH" = "clangarm64" ]; then
+    CONFIG[9]="${CONFIG[9]} -D GGML_BLAS=OFF"
+  else
+    CONFIG[9]="${CONFIG[9]} -D GGML_AVX2=OFF -D GGML_BLAS=ON -D GGML_BLAS_VENDOR=OpenBLAS"
+  fi
   CFLAGS_[9]=$CFLAGS
   LDFLAGS_[9]=$LDFLAGS
+  BUILD[9]="ninja -C build -j $MAKEJ"
+  INSTALL[9]="install_whispercpp"
 
   #####
   # dav1d
@@ -644,14 +689,19 @@ function set_globals {
   else
     CONFIG[12]="${CONFIG[12]} --buildtype=release"
   fi
-  CFLAGS_[12]=$CFLAGS
-  LDFLAGS_[12]=$LDFLAGS
+  CFLAGS_[12]="$CFLAGS"
+  [ "$TARGET_ARCH" = "clangarm64" ] && LDFLAGS_[12]="$LDFLAGS -lwinpthread"
   BUILD[12]="ninja -C libvmaf/build -j $MAKEJ"
   INSTALL[12]="install_vmaf"
 
   #####
   # glaxnimate
-  CONFIG[13]="cmake -G Ninja -D CMAKE_PREFIX_PATH=$QTDIR -D CMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -D Python3_FIND_REGISTRY=NEVER"
+  CONFIG[13]="cmake -G Ninja -D CMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR -D Python3_FIND_REGISTRY=NEVER"
+  if [ "$TARGET_ARCH" = "clangarm64" ]; then
+    CONFIG[13]="${CONFIG[13]} -D CMAKE_CXX_FLAGS=-DPYBIND11_EXPORT_EXCEPTION= -D CMAKE_PREFIX_PATH=$FINAL_INSTALL_DIR"
+  else
+    CONFIG[13]="${CONFIG[13]} -D CMAKE_PREFIX_PATH=$QTDIR"
+  fi
   if [ "$DEBUG_BUILD" = "1" ]; then
     CONFIG[13]="${CONFIG[13]} -D CMAKE_BUILD_TYPE=RelWithDebInfo"
   else
@@ -677,6 +727,14 @@ function set_globals {
   LDFLAGS_[15]="$LDFLAGS"
   BUILD[15]="ninja -C build -j $MAKEJ"
   INSTALL[15]="ninja -C build install"
+
+  #####
+  # libspatialaudio
+  CONFIG[17]="cmake -G Ninja -B build -D CMAKE_INSTALL_PREFIX=$FINAL_INSTALL_DIR $CMAKE_DEBUG_FLAG"
+  CFLAGS_[17]="$CFLAGS"
+  LDFLAGS_[17]="$LDFLAGS"
+  BUILD[17]="ninja -C build -j $MAKEJ"
+  INSTALL[17]="install_spatialaudio"
 }
 
 function build_dav1d {
@@ -693,18 +751,33 @@ function install_amf {
 function install_shotcut {
   cmd ninja install
   cmd install -c COPYING "$FINAL_INSTALL_DIR"
-  cmd install -c packaging/windows/shotcut.nsi "$FINAL_INSTALL_DIR"/..
-  cmd sed -i "s/YY.MM.DD/$SHOTCUT_VERSION/" "$FINAL_INSTALL_DIR"/../shotcut.nsi
+  cmd install -c packaging/windows/shotcut.iss "$FINAL_INSTALL_DIR"/..
+  cmd sed -i "s/YY.MM.DD/$SHOTCUT_VERSION/" "$FINAL_INSTALL_DIR"/../shotcut.iss
   cmd install -d "$FINAL_INSTALL_DIR"/share/translations
   cmd install -p -c translations/*.qm "$FINAL_INSTALL_DIR"/share/translations
 }
 
+function install_ladspa-swh {
+  cmd install -d "$FINAL_INSTALL_DIR"/lib/ladspa
+  cmd install -p -c .libs/*.dll "$FINAL_INSTALL_DIR"/lib/ladspa
+}
+
 function install_vmaf {
   cmd ninja install -C libvmaf/build || die "Unable to install $1"
   cmd install -d "$FINAL_INSTALL_DIR"/share/vmaf
   cmd install -p -c model/*.json "$FINAL_INSTALL_DIR"/share/vmaf || die "Unable to install $1"
 }
 
+function install_spatialaudio {
+  cmd ninja -C build install || die "Unable to install $1"
+  cmd sed -i "s,-I/${TARGET_ARCH}/include,," "$FINAL_INSTALL_DIR"/lib/pkgconfig/spatialaudio.pc
+}
+
+function install_whispercpp {
+  cmd ninja -C build install
+  cmd install -p -c build/bin/whisper-cli.exe $FINAL_INSTALL_DIR/bin
+}
+
 ######################################################################
 # FEEDBACK FUNCTIONS
 ######################################################################
@@ -1088,17 +1161,6 @@ function sys_info {
   uname -a
   echo Information about cc at the time of compilation:
   LANG=C cc -v 2>&1
-  if which dpkg ; then
-    echo Found dpkg - running dpkg -l to grep libc6
-    dpkg -l | grep libc6
-  else
-    if which rpm ; then
-      echo Found rpm - running rpm -qa to grep libc6
-      rpm -qa | grep libc
-    else
-      echo Found neither dpkg or rpm...
-    fi
-  fi
 }
 
 
@@ -1109,7 +1171,7 @@ function bundle_dlls
   log bundling library dependencies of $(basename "$1")
   target=$(dirname "$1")/$(basename "$1")
   basename_target=$(basename "$target")
-  libs=$(ldd "$target" | awk '($3 ~ /\/mingw64\/bin\//) {print $3}')
+  libs=$(ldd "$target" | awk "(\$3 ~ /\/$TARGET_ARCH\/bin\//) {print \$3}")
   for lib in $libs; do
     basename_lib=$(basename "$lib")
     if [ "$basename_lib" != "$basename_target" ]; then
@@ -1144,19 +1206,20 @@ function deploy
   if [ "$SDK" = "1" ]; then
     cmd mv bin/*.exe .
     # OpenCV installs binaries to a weird place
-    cmd cp x64/mingw/bin/*.dll .
+    cmd mv {x64,x86}/mingw/bin/*.dll .
   else
     cmd mv bin/ffmpeg.exe .
     cmd mv bin/ffplay.exe .
     cmd mv bin/ffprobe.exe .
     cmd mv bin/glaxnimate.exe .
+    cmd mv bin/whisper-cli.exe .
     cmd rm -rf bin include etc man manifest src *.txt
     cmd rm lib/*
     cmd rm -rf lib/cmake lib/pkgconfig lib/gdk-pixbuf-2.0 lib/glib-2.0 lib/gtk-2.0
     cmd rm -rf share/doc share/man share/ffmpeg/examples share/aclocal share/glib-2.0 share/gtk-2.0 share/gtk-doc share/themes share/locale
     # OpenCV installs binaries to a weird place
-    cmd mv x64/mingw/bin/*.dll .
-    cmd rm -rf x64
+    cmd mv {x64,x86}/mingw/bin/*.dll .
+    cmd rm -rf {x64,x86}
     cmd rm OpenCVConfig*
     cmd rm setup_vars_opencv4.cmd
   fi
@@ -1164,12 +1227,7 @@ function deploy
 
   log Copying some libs from Qt
   if [ "$DEBUG_BUILD" != "1" -o "$SDK" = "1" ]; then
-    cmd cp -p "$QTDIR"/bin/Qt6{Core,Core5Compat,Gui,Multimedia,Network,OpenGL,OpenGLWidgets,Qml,QmlModels,QmlWorkerScript,Quick,QuickControls2,QuickControls2Impl,QuickDialogs2,QuickDialogs2QuickImpl,QuickDialogs2Utils,QuickLayouts,QuickTemplates2,QuickWidgets,Sql,Svg,SvgWidgets,UiTools,Widgets,Xml}.dll .
-  fi
-
-  if [ "ENABLE_SWH_PLUGINS" != "1" ]; then
-    log Copying LADSPA plugins
-    cmd tar -xJf "$HOME/swh-plugins-win64-0.4.15.tar.xz"
+    cmd cp -p "$QTDIR"/bin/Qt6{Charts,Core,Core5Compat,Gui,Multimedia,Network,OpenGL,OpenGLWidgets,Qml,QmlMeta,QmlModels,QmlWorkerScript,Quick,QuickControls2*,QuickDialogs2,QuickDialogs2QuickImpl,QuickDialogs2Utils,QuickLayouts,QuickTemplates2,QuickWidgets,Sql,Svg,SvgWidgets,UiTools,Widgets,Xml}.dll .
   fi
 
   for lib in *.dll; do
@@ -1179,14 +1237,18 @@ function deploy
     bundle_dlls "$lib"
   done
   bundle_dlls glaxnimate.exe
+  # for good measure
+  for lib in $(find -name '*.dll' -or -name '*.exe'); do
+    bundle_dlls "$lib"
+  done
 
   log Copying some DLLs and python libraries for Glaxnimate
-  cmd cp -p /mingw64/bin/libpython3.10.dll python310.dll
+  cmd cp -p /${TARGET_ARCH}/bin/libpython${PYTHON_VERSION}.dll python${PYTHON_VERSION_DLL}.dll
   cmd cp -p "$SOURCE_DIR"/glaxnimate/external/Qt-Color-Widgets/libQtColorWidgets.dll .
   cmd mkdir -p share/glaxnimate/glaxnimate/pythonhome/lib/python
-  cmd cp -r /mingw64/lib/python3.10/*.py \
-            /mingw64/lib/python3.10/lib-dynload/* \
-            /mingw64/lib/python3.10/{json,collections,encodings,logging,urllib} \
+  cmd cp -r /${TARGET_ARCH}/lib/python${PYTHON_VERSION}/*.py \
+            /${TARGET_ARCH}/lib/python${PYTHON_VERSION}/lib-dynload/* \
+            /${TARGET_ARCH}/lib/python${PYTHON_VERSION}/{json,collections,encodings,logging,urllib} \
       share/glaxnimate/glaxnimate/pythonhome/lib/python
 
   log Copying some libs from mlt-prebuilt
@@ -1194,32 +1256,39 @@ function deploy
   cmd cp -p "$QTDIR"/bin/d3dcompiler_47.dll .
 
   log Copying some libs from msys2
-  cmd cp -p /mingw64/bin/{libcrypto-1_1-x64,libssl-1_1-x64}.dll .
+  cmd cp -p /${TARGET_ARCH}/bin/libcrypto-3.dll .
+  if [ "$TARGET_ARCH" = "clangarm64" ]; then
+    cmd cp -p /${TARGET_ARCH}/bin/{libjasper.dll,libjpeg-8.dll,libmng-2.dll,liblcms2-2.dll,libtiff-6.dll,libjbig-0.dll,libdeflate.dll,libLerc.dll,libunwind.dll,libwebpdemux-2.dll,libcairo-2.dll,libfontconfig-1.dll,libpixman-1-0.dll,libxml2-2.dll,libomp.dll,libebur128.dll,libsamplerate-0.dll,librubberband-2.dll,libsox-3.dll,libopencore-amrnb-0.dll,libvo-amrwbenc-0.dll,libFLAC.dll,libltdl-7.dll,libgsm.dll,libmad-0.dll,libao-4.dll,libid3tag-0.dll,libtwolame-0.dll,libvorbisfile-3.dll,libwavpack-1.dll,libsndfile-1.dll,libopencore-amrwb-0.dll,libmpg123-0.dll,libopusfile-0.dll,libmysofa.dll,libvidstab.dll,libexpat-1.dll,liblz4.dll,libfftw3f-3.dll} .
+  fi
   if [ "$DEBUG_BUILD" = "1" -o "$SDK" = "1" ]; then
-    cmd cp -p "$SOURCE_DIR"/shotcut/drmingw/x64/bin/*.{dll,yes} .
-    cmd cp -p /mingw64/bin/libfftw3*.dll bin/
-    cmd cp -p /mingw64/lib/libfftw3*.a lib/
-    cmd cp -p /mingw64/include/fftw3* include/
-    cmd cp -p /mingw64/lib/pkgconfig/fftw3*.pc lib/pkgconfig/
+    [ "$TARGET_ARCH" != "clangarm64" ] && cmd cp -p "$SOURCE_DIR"/shotcut/drmingw/x64/bin/*.{dll,yes} .
+    cmd cp -p /${TARGET_ARCH}/bin/libfftw3*.dll bin/
+    cmd cp -p /${TARGET_ARCH}/lib/libfftw3*.a lib/
+    cmd cp -p /${TARGET_ARCH}/include/fftw3* include/
+    cmd cp -p /${TARGET_ARCH}/lib/pkgconfig/fftw3*.pc lib/pkgconfig/
 #    cmd mkdir -p lib/cmake/fftw3 lib/cmake/fftw3f lib/cmake/fftw3l lib/cmake/fftw3q
-#    cmd cp -p /mingw64/lib/cmake/fftw3/*.cmake lib/cmake/fftw3/
-#    cmd cp -p /mingw64/lib/cmake/fftw3f/*.cmake lib/cmake/fftw3f/
-#    cmd cp -p /mingw64/lib/cmake/fftw3l/*.cmake lib/cmake/fftw3l/
-#    cmd cp -p /mingw64/lib/cmake/fftw3q/*.cmake lib/cmake/fftw3q/
+#    cmd cp -p /${TARGET_ARCH}/lib/cmake/fftw3/*.cmake lib/cmake/fftw3/
+#    cmd cp -p /${TARGET_ARCH}/lib/cmake/fftw3f/*.cmake lib/cmake/fftw3f/
+#    cmd cp -p /${TARGET_ARCH}/lib/cmake/fftw3l/*.cmake lib/cmake/fftw3l/
+#    cmd cp -p /${TARGET_ARCH}/lib/cmake/fftw3q/*.cmake lib/cmake/fftw3q/
   fi
 
   log Copying some plugins, qml, and translations from Qt
-  cmd mkdir -p lib/qt6/audio
-  for plugin in audio generic iconengines imageformats multimedia platforms sqldrivers styles tls; do
-    cmd cp -pr "$QTDIR"/plugins/${plugin} lib/qt6
+  cmd mkdir -p lib/qt6/generic
+  for plugin in generic iconengines imageformats multimedia platforms sqldrivers styles tls; do
+    cmd cp -pr "$QT_SHARE_DIR"/plugins/${plugin} lib/qt6
+    cmd rm lib/qt6/${plugin}/*.debug 2>/dev/null
+    cmd rm lib/qt6/multimedia/ffmpegmediaplugin.dll 2>/dev/null
+    cmd rm lib/qt6/tls/qcertonlybackend.dll 2>/dev/null
+    cmd rm lib/qt6/tls/qopensslbackend.dll 2>/dev/null
     for lib in lib/qt6/${plugin}/*.dll; do
       bundle_dlls "$lib"
     done
   done
   cmd mkdir -p lib/qml
-  cmd cp -pr "$QTDIR"/qml/{Qt,QtCore,QtQml,QtQuick} lib/qml
-  cmd cp -pr "$QTDIR"/translations/qt_*.qm share/translations
-  cmd cp -pr "$QTDIR"/translations/qtbase_*.qm share/translations
+  cmd cp -pr "$QT_SHARE_DIR"/qml/{Qt,QtCore,QtQml,QtQuick} lib/qml
+  cmd cp -pr "$QT_SHARE_DIR"/translations/qt_*.qm share/translations
+  cmd cp -pr "$QT_SHARE_DIR"/translations/qtbase_*.qm share/translations
 
   log Removing things not needed
   cmd rm *.bundled
